=========
palletier
=========


.. image:: https://img.shields.io/pypi/v/palletier.svg
        :target: https://pypi.python.org/pypi/palletier

.. image:: https://img.shields.io/travis/alanbato/palletier.svg
        :target: https://travis-ci.org/alanbato/palletier

.. image:: https://readthedocs.org/projects/palletier/badge/?version=latest
        :target: https://palletier.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Palletier is a Python implementation of the solution for the distributer's
pallet packing problem presented by Erhan Baltacioğlu in his thesis
*The distributer's three-dimensional pallet-packing problem: a human intelligence-based heuristic approach* found here.

* Free software: MIT license
* Documentation: https://palletier.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
